

class ObjectNotFound(Exception):
    """Exception raised when an expected object is not found"""

class InvalidOperation(Exception):
    """Exeception raised when an operation doesnt make sense"""


